@@ -3,7 +3,7 @@
 # Copyright (C) 2002 Antti Kmrinen <antti at seu.net>
 # Copyright (C) 2007-2008 Mikko Hynninen <first.last at tietokartano.fi>
 # --
-# $Id: fi.pm,v 1.78 2008/07/27 10:22:33 martin Exp $
+# $Id: fi.pm,v 1.80 2008/09/24 11:39:25 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -16,7 +16,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.78 $) [1];
+$VERSION = qw($Revision: 1.80 $) [1];
 
 sub Data {
     my $Self = shift;
@@ -1525,6 +1525,8 @@ sub Data {
         'Priority Management' => 'Prioriteettien hallinta',
         'Add a new Priority.' => 'Lis uusi prioriteetti.',
         'Add Priority' => 'Lis prioriteetti',
+        'Ticket Type is required!' => '',
+        'Module documentation' => '',
     };
     # $$STOP$$
     return;
